==> sems-0.8.12.tar.gz: sems-0.8.12/plug-in/bot/Bot.cpp <==
/*
 * $Id: Bot.cpp,v 1.3.2.1 2005/08/25 07:54:05 rco Exp $
 *
 * Copyright (C) 2002-2003 Fhg Fokus
 *
 * This file is part of sems, a free SIP media server.
 *
 * sems is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * For a license to use the sems software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * sems is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "Bot.h"

#include "AmUtils.h"
#include "log.h"

EXPORT_FACTORY(BotStateFactory,"bot");

BotStateFactory::BotStateFactory(const string& _app_name)
    : AmStateFactory(_app_name)
{
}

AmDialogState* BotStateFactory::onInvite(AmCmd& cmd)
{
    return new BotDialog();
}

int BotStateFactory::onLoad()
{
    return AmServer::instance()->registerFct("bot_start",this);
}

int BotStateFactory::execute(FILE* stream, const string& cmd_str)
{
    char line_buf[MAX_LINE_SIZE];
    string uri,from_user,input_file,output_file;

    if(cmd_str == "duplex"){

	READ_FIFO_PARAMETER(stream,uri,line_buf,MAX_LINE_SIZE);
	READ_FIFO_PARAMETER(stream,from_user,line_buf,MAX_LINE_SIZE);
	READ_FIFO_PARAMETER(stream,input_file,line_buf,MAX_LINE_SIZE);
	READ_FIFO_PARAMETER(stream,output_file,line_buf,MAX_LINE_SIZE);
	
	AmCmd cmd(AmRequestUAC::dialout(input_file+":"+output_file,
					"bot",uri,from_user));
    }
    else {
	throw string("BotStateFactory::execute: unknown subcommand.");
    }

    return 0;
}

BotDialog::BotDialog()
{
    DBG("BotDialog::BotDialog\n");
}

BotDialog::~BotDialog()
{
    DBG("BotDialog::~BotDialog\n");
}

void BotDialog::onSessionStart(AmRequest* req)
{
    DBG("BotDialog::onSessionStart\n");

    string in_file,out_file;
    string::size_type pos = req->cmd.user.find(':');

    if(pos != string::npos){

	in_file  = req->cmd.user.substr(0,pos);
	out_file = req->cmd.user.substr(pos+1,string::npos);

	AmAudioFile in_audio("Wav");
	//in_audio.loop.set(true);
	in_audio.open(in_file.c_str(),AmAudioFile::Read);

	AmAudioFile out_audio("Wav",1/* PCM16 */);
	out_audio.open(out_file.c_str(),AmAudioFile::Write);

	getSession()->rtp_str.duplex(&in_audio,&out_audio);
    }
    
    if(!getSession()->sess_stopped.get())
	req->bye();
    DBG("BotDialog::onSessionStart finished\n");
}

void BotDialog::onBye(AmRequest* req)
{
    DBG("BotDialog::onBye\n");
}

==> sems-0.9.0.tar.gz: sems-0.9.0/plug-in/bot/Bot.cpp <==
/*
 * $Id: Bot.cpp,v 1.4.4.1 2005/08/25 09:34:21 rco Exp $
 *
 * Copyright (C) 2002-2003 Fhg Fokus
 *
 * This file is part of sems, a free SIP media server.
 *
 * sems is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * For a license to use the sems software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * sems is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "Bot.h"

#include "AmUtils.h"
#include "log.h"

EXPORT_FACTORY(BotStateFactory,"bot");

BotStateFactory::BotStateFactory(const string& _app_name)
    : AmStateFactory(_app_name)
{
}

AmDialogState* BotStateFactory::onInvite(AmCmd& cmd)
{
    return new BotDialog();
}

int BotStateFactory::onLoad()
{
    return AmUnServer::instance()->registerFct("bot_start",this) ||
	AmFifoServer::instance()->registerFct("bot_start",this);
}

int BotStateFactory::execute(FILE* stream, const string& cmd)
{
    char line_buf[MAX_LINE_SIZE];
    string uri,from_user,input_file,output_file;

    if(cmd == "duplex"){

	READ_FIFO_PARAMETER(stream,uri,line_buf,MAX_LINE_SIZE);
	READ_FIFO_PARAMETER(stream,from_user,line_buf,MAX_LINE_SIZE);
	READ_FIFO_PARAMETER(stream,input_file,line_buf,MAX_LINE_SIZE);
	READ_FIFO_PARAMETER(stream,output_file,line_buf,MAX_LINE_SIZE);
	
	AmCmd cmd(AmRequestUAC::dialout(input_file+":"+output_file,
					"bot",uri,from_user));
    }
    else {
	throw string("BotStateFactory::execute: unknown subcommand.");
    }

    return 0;
}

int BotStateFactory::execute(char* msg_c, const string& cmd_str)
{
    string uri,from_user,input_file,output_file;

    if(cmd_str == "duplex"){

	msg_get_param(msg_c,uri);
	msg_get_param(msg_c,from_user);
	msg_get_param(msg_c,input_file);
	msg_get_param(msg_c,output_file);
	
	AmCmd cmd(AmRequestUAC::dialout(input_file+":"+output_file,
					"bot",uri,from_user));
    }
    else {
	throw string("BotStateFactory::execute: unknown subcommand.");
    }

    return 0;
}

BotDialog::BotDialog()
{
    DBG("BotDialog::BotDialog\n");
}

BotDialog::~BotDialog()
{
    DBG("BotDialog::~BotDialog\n");
}

void BotDialog::onSessionStart(AmRequest* req)
{
    DBG("BotDialog::onSessionStart\n");

    string in_file,out_file;
    string::size_type pos = req->cmd.user.find(':');

    if(pos != string::npos){

	in_file  = req->cmd.user.substr(0,pos);
	out_file = req->cmd.user.substr(pos+1,string::npos);

	AmAudioFile in_audio("Wav");
	//in_audio.loop.set(true);
	in_audio.open(in_file.c_str(),AmAudioFile::Read);

	AmAudioFile out_audio("Wav",1/* PCM16 */);
	out_audio.open(out_file.c_str(),AmAudioFile::Write);

	getSession()->rtp_str.duplex(&in_audio,&out_audio);
    }
    
    if(!getSession()->sess_stopped.get())
	req->bye();
    DBG("BotDialog::onSessionStart finished\n");
}

void BotDialog::onBye(AmRequest* req)
{
    DBG("BotDialog::onBye\n");
}
